CodecResult class

Represents the result of encode/decode routines.

Constructors

CodecResult(int readCount, int writeCount, {bool adjustBufferCounts = true})
Construct a CodecResult that defines the number of bytes that were read and written by a Codec routine.
const

Properties

adjustBufferCounts → bool
The read/write buffer counts will be incremented by the readCount and writeCount
final
hashCode → int
The hash code for this object.
no setterinherited
readCount → int
Number of bytes read by codec routine
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writeCount → int
Number of bytes written by codec routine
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited