DartCodecFilterBase class abstract

Provides a base-class for codec filters that need to use Dart heap-allocated buffers instead of ffi-based buffers.

Inheritance

Constructors

DartCodecFilterBase({int inputBufferLength = 16386, int outputBufferLength = 16386})
Constructor which allows the user to set the input/output buffer lengths.

Properties

closed → bool
Return true if filter is in closed state.
no setterinherited
finalized → bool
Return true if filter is in finalized state.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
init → bool
Return true if filter is in init state.
no setterinherited
processing → bool
Return true if filter is in opened state.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ CodecFilterState
State tracker for filters.
getter/setter pairinherited

Methods

close() → void
Close this filter if not already closed.
inherited
doClose() → void
Perform tear-down procedures.
override
doFinalize(DartCodecBuffer outputBuffer) → int
Perform algorithm-specific finalization.
override
doFlush(DartCodecBuffer outputBuffer) → int
Flush the internal-algorithm buffered output data.
override
doInit(CodecBufferHolder<DartHeapPointer, DartCodecBuffer> inputBufferHolder, CodecBufferHolder<DartHeapPointer, DartCodecBuffer> outputBufferHolder, List<int> bytes, int start, int end) → int
Init the filter.
override
doProcessing(DartCodecBuffer inputBuffer, DartCodecBuffer outputBuffer) → CodecResult
Subclass Responsibility: Algorithm-specific coding/decoding handler
inherited
hasMoreToProcess() → bool
Return true if there is more data to process, false otherwise.
inherited
newBufferHolder(int length) → CodecBufferHolder<DartHeapPointer, DartCodecBuffer>
Return a DartCodecBufferHolder with the intended length.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(List<int> data, int start, int end) → void
Process a chunk of data from start to end. A call to process should only be made when processed returns null.
inherited
processed({bool flush = true, bool end = false}) → List<int>?
Return a chunk of processed data.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited