ZstdCodec class

The ZstdCodec encodes/decodes raw bytes using the Zstd (ZStandard) algorithm.

Inheritance

Constructors

ZstdCodec({int level = ZstdOption.defaultLevel, int inputBufferLength = CodecBufferHolder.autoLength, int outputBufferLength = CodecBufferHolder.autoLength})
Construct an ZstdCodec that is configured with the following parameters.

Properties

bindingVersion → ZstdVersion
Return the base binding version this binding code was developed for.
no setter
decoder → Converter<List<int>, List<int>>
Return the zstd decoder configured implementation.
no setteroverride
encoder → Converter<List<int>, List<int>>
Return the zstd encoder configured implementation.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inputBufferLength → int
Length in bytes of the buffer used for input data.
final
inverted → Codec<List<int>, List<int>>
Inverts this.
no setterinherited
level → int
The compression-level can be set in the range of 0..16, with 0 (fast mode) being the default compression level.
final
libraryVersion → ZstdVersion
Return the actual library version of the shared library.
no setter
outputBufferLength → int
Length in bytes of the buffer used for processed output data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(List<int> encoded) → List<int>
Decodes encoded data.
inherited
encode(List<int> input) → List<int>
Encodes input.
inherited
fuse<R>(Codec<List<int>, R> other) → Codec<List<int>, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

libraryPath ↔ String?
Return the library path String or null if not set.
getter/setter pair