ZstdVersion class

Helper class to decode the version number returned from the zstd FFI library.

Constructors

ZstdVersion(int versionNumber)
Construct a new ZstdVersion.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
major → int
Return the major element of the version.
no setter
minor → int
Return the minor element of the version.
no setter
patch → int
Return the patch element of the version.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionNumber → int
Encoded version number from zstd.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Return the String repr of the versionNumber.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited